..
    :copyright: Copyright (c) 2015 ftrack

.. _api_reference/resource_identifier_transformer:

******************************************
ftrack_api.resource_identifier_transformer
******************************************

.. automodule:: ftrack_api.resource_identifier_transformer

.. toctree::
    :maxdepth: 1
    :glob:

    *
